--[[
	Project: LowHealthAlarm
	Friendly Name: Low Health Alarm
	Author: Vandesdelca32

	File: init.lua
	Purpose: Initialization/Setup

	Version: 2

	ALL RIGHTS RESERVED.
	COPYRIGHT (c)2016 VANDESDELCA32
]]

local AppName, App = ...

-- Get the libraries loaded up
local MyAddon = LibStub("AceAddon-3.0"):NewAddon(AppName, "AceEvent-3.0", "AceTimer-3.0")
local LSM = LibStub("LibSharedMedia-3.0")

LibStub("LibVan32-1.0"):Embed(MyAddon, AppName)

MyAddon._Major = "r5"
MyAddon._Revision = "5"

-- GLOBALS: SLASH_LOWHEALTHALARM1,SLASH_LOWHEALTHALARM2,SLASH_LOWHEALTHALARM3
-- GLOBALS: SlashCmdList, LowHealthAlarm_DB, format

-- Initialize Options...
local AppDefaults = {
	_VER				= 3,
	Enabled			= true,
	LoginMessage	= true,
	HP_CRITICAL		= 0.10,
	HP_WARNING		= 0.25,
	HP_LOW			= 0.40,
	Base				= 1.0,
	Multiplier		= 2.0,
	BeepFile			= "LoZ: Link to the Past Beep",
	BeepVolume		= 3,
	SoundChannel	= "SFX",
}

local function Get( info )
	return LowHealthAlarm_DB[info[#info]]
end

local function Set( info, value )
	LowHealthAlarm_DB[info[#info]] = value
end

MyAddon.Options = {
	type = "group",
	name = AppName,
	get = Get,
	set = Set,
	args = {},
}

local L = LibStub("AceLocale-3.0"):GetLocale(AppName)
App[1] = MyAddon			-- The entire addon.
App[2] = L			-- Localization data when I get there.
App[3] = AppDefaults 			-- Default settings table
_G[AppName] = App

function MyAddon:OnInitialize()
	-- Do init tasks here, like loading the Saved Variables,
	-- or setting up slash commands.
	SLASH_LOWHEALTHALARM1 = "/lh"
	SLASH_LOWHEALTHALARM2 = "/lha"
	SLASH_LOWHEALTHALARM3 = "/lowhealth"

	-- Handle slash commands (just going to open the config dialog)
	SlashCmdList["LOWHEALTHALARM"] = function(...)
		self:ToggleOptions()
	end

	self:CheckSettingsDB()

	-- Add in our sounds...
	LSM:Register("sound", "LoZ: Link to the Past Beep", [[Interface\AddOns\LowHealthAlarm\media\LTTP_LowHealth.ogg]])

	self:SetEnabledState(self:GetSetting("Enabled"))
	for _, module in self:IterateModules() do
		module:SetEnabledState(self:GetSetting("Enabled"))
	end
end

function MyAddon:OnEnable()
	-- Do more initialization here, that really enables the use of your addon.
	-- Register Events, Hook functions, Create Frames, Get information from
	-- the game that wasn't available in OnInitialize
	local verStr = self:GetVersion(false, true)
	if self:GetSetting("LoginMessage") then
		self:PrintMessage(format(L["CHAT/LoginMessage"], verStr))
	end

	self:RegisterEvent("UNIT_HEALTH_FREQUENT")
	self:RegisterEvent("PLAYER_DEAD")
end

function MyAddon:OnDisable()
  -- Unhook, Unregister Events, Hide frames that you created.
  -- You would probably only use an OnDisable if you want to
  -- build a "standby" mode, or be able to toggle modules on/off.
  self:UnregisterEvent("UNIT_HEALTH_FREQUENT")
  self:UnregisterEvent("PLAYER_DEAD")
  self:SetBeepSpeed(0)
end

